<!DOCTYPE TS><TS>
<context>
    <name>AudioControl</name>
    <message>
        <source>Audio Properties</source>
        <translation>Propriedades do Audio</translation>
    </message>
    <message>
        <source>OSS Device Mode</source>
        <translation>Modo Dispositivo OSS</translation>
    </message>
    <message>
        <source>ReadWrite</source>
        <translation>Leitura/Escrita</translation>
    </message>
    <message>
        <source>ReadOnly / WriteOnly</source>
        <translation>Somente Leitura / Somente Escrita</translation>
    </message>
    <message>
        <source>Device for WriteOnly or ReadWrite:</source>
        <translation>Dispositivo para Somente Escrita ou Somente Leitura:</translation>
    </message>
    <message>
        <source>Device for ReadOnly:</source>
        <translation>Dispositivo para Somente Escrita:</translation>
    </message>
    <message>
        <source>Preferred Codec</source>
        <translation>Codec Preferido</translation>
    </message>
    <message>
        <source>G711u</source>
        <translation></translation>
    </message>
    <message>
        <source>GSM</source>
        <translation></translation>
    </message>
    <message>
        <source>iLBC</source>
        <translation></translation>
    </message>
    <message>
        <source>Size of Payload</source>
        <translation>Tamanho do Pacote</translation>
    </message>
    <message>
        <source>80 (10 ms Sample)</source>
        <translation></translation>
    </message>
    <message>
        <source>160 (20 ms Sample)</source>
        <translation></translation>
    </message>
    <message>
        <source>Ringing tone  (system bell)</source>
        <translation>Tom de chamada(Campainha do sistema)</translation>
    </message>
    <message>
        <source>Don&apos;t use ringing tone</source>
        <translation>Não usar tom de chamada</translation>
    </message>
    <message>
        <source>Use ringing tone</source>
        <translation>Usar tom de chamada</translation>
    </message>
    <message>
        <source>ok button</source>
        <translation></translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>cancel button</source>
        <translation>Cancelar botão</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
</context>
<context>
    <name>CallAudio</name>
    <message>
        <source>CallAudio: SendToRemote called but we don&apos;t have a valid session description yet</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CallAudio: Remote is currently putting us on hold, waiting patiently</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CallAudio: Sending to remote site %s:%d</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CallAudio: OSS device already open (readwrite)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>** audioIn: openDevice Failed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CallAudio: Opening OSS device %s for Input</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CallAudio: Creating OSS-&gt;RTP Diverter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CallAudio: Opening SW for video input and output</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CallAudio: listening for incomming RTP</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CallAudio: Opening OSS device %s for Input and Output</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>** audioOut: openDevice Failed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CallAudio: Opening OSS device %s for Output</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ContactParser</name>
    <message>
        <source>description</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>uri</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>contact</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ContactsListView</name>
    <message>
        <source>Status</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Contact</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DspAudioIn</name>
    <message>
        <source>DspAudioIn: Broken pipe</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DspAudioIn: UDP-failure(%d)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DspAudioOut</name>
    <message>
        <source>DspAudio: Broken pipe</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DspOutOss</name>
    <message>
        <source>Device Already Open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open Failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Format not supported</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unsupported Number of Channels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>WARNING: nonmonophonic driver, forced into stereo mode (experimental)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>WARNING: driver rounded %d Hz request to %d Hz, off by %f%%</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Device Not Open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>warning: asked microphone for %d got %d</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DspOutRtp</name>
    <message>
        <source>DspOutRtp:: Can&apos;t create socket</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DspOutRtp::Hostname lookup failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SipClient: Receiving message...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SipClient: STUN response for RTP</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>KCallTransfer</name>
    <message>
        <source>Transfer to URI:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>help button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;help...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ok button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>cancel button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>KCallWidget</name>
    <message>
        <source>Remote: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>  Remote:  </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Status: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Dial</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hangup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hold</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Transfer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DTMF</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hide</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>KCallWidget: Switching calls...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Call: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Incoming Video Call: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Incoming Call: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Accept</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reject</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Outgoing Video Call: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Outgoing Call: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error: No Destination</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You must specify someone to call.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Close any program which might be using soundcard 
and then retry dial.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>KCallAudio: Broken output pipe, disconnecting unpolitely</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unhold</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>KCallWidget: Handling redirect...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Redirect</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Call redirected to: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Do you want to proceed ? </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>KCallWidget: Starting force disconnect...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Attached [holding]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Attached [active]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unattached</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Accept Call</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Close any program which might be using soundcard 
and then retry accepting call.</source>
        <translation></translation>
    </message>
    <message>
        <source>Accepted codec not found.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>KInstantMessageWidget</name>
    <message>
        <source> Message - KPhone</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remote: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>  Remote:  </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Status: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Message: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Send</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hide</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Message received from </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error: No Destination</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You must specify someone to send message.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Message sent to </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>KPhone</name>
    <message>
        <source>New Call...</source>
        <translation>Nova chamada...</translation>
    </message>
    <message>
        <source>New Video Call...</source>
        <translation>Nova chamada de vídeo...</translation>
    </message>
    <message>
        <source>Identity...</source>
        <translation>Identidade...</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Sair</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Arquivo</translation>
    </message>
    <message>
        <source>SIP Preferences...</source>
        <translation>Preferências do SIP...</translation>
    </message>
    <message>
        <source>Audio Preferences...</source>
        <translation>Preferências de Audio...</translation>
    </message>
    <message>
        <source>Video Preferences...</source>
        <translation>Preferências de Vídeo...</translation>
    </message>
    <message>
        <source>Phone Book</source>
        <translation>Agenda Telefônica</translation>
    </message>
    <message>
        <source>Tray Icon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Preferences</source>
        <translation>&amp;Preferências</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <source>About KPhone</source>
        <translation>Sobre KPhone</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Ajuda</translation>
    </message>
    <message>
        <source>When starting KPhone for the first time, you should enter your identity information in the window appearing.
The information required for successful sipping are &apos;Full Name&apos;, &apos;User part of SIP URL&apos; and &apos;Host part of SIP URL&apos;.
Note for KPhone 3.xx users: copy &apos;~/.kde/share/config/kphonerc&apos; file to &apos;~/.qt&apos; directory.

If you have a NAPTR/SRV enabled DNS-server you can leave the &apos;Outbound Proxy&apos; and &apos;Authentication Username&apos; fields empty,
as KPhone will automatically search for the server information by the &apos;Host part of SIP URL&apos; and prompt the username/password.

Mark the auto register selection if you wish KPhone to automatically register your identity on application start.
If you want to use multiple identities, start KPhone with the &apos;-u&apos; option and the username of your selection.
For example:  &apos;kphone -u jsmith&apos;.

If you are behind a NAT (Network Address Translation) device, you should go to Preferences -&gt; SIP Preferences -&gt; Socket and
check the &apos;Use STUN Server&apos;

The right button of your mouse is your best friend in KPhone&apos;s main UI. By clicking the right mouse button (RMB) in the main
window you get a menu including all important functions of KPhone. You should edit the Phone Book and enter all your favourite
contacts there. Of course this is not mandatory but it increases your efficiency with KPhone.

When adding contacts to your Phone Book, simply click Add and enter the person&apos;s real name, SIP identity and the optional
description. If you want your contacts to be displayed in the main UI, just check the &apos;Add Identity ...&apos; box. After editing your
contacts you can return to the main UI by clicking Hide. All your selected contacts should now appear there. Making calls and 
sending instant messages to your contacts is easy with the RMB. Just click and select the function which you&apos;d like to initiate.
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>is a &apos;Voice Over Internet&apos; phone</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copyright (c) 2000 Billy Biggs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copyright (c) 2004 Wirlab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>KPhone is released under the GPL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>For more information, see</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>KPhoneView</name>
    <message>
        <source>Set Identity</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Send Message</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Call</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video Call</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Phone Book</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Online</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Busy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Be Right Back</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Away</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>On The Phone</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Out To Lunch</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>KPhoneView: Incoming Instant Message</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>KPhone</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Subscribe message from uri:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Do you want to accept and create a contact ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Accept</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reject permanently</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reject this time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Incoming call</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set First Identity.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>online</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>busy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>berightback</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>away</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>onthephone</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>outtolunch</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>KSipAuthenticationRequest</name>
    <message>
        <source>SipUri = </source>
        <translation>SIP URI = </translation>
    </message>
    <message>
        <source>Server = </source>
        <translation>Servidor = </translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Usuário:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Senha:</translation>
    </message>
    <message>
        <source>ok button</source>
        <translation>botão OK</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>cancel button</source>
        <translation>botão cancelar</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
</context>
<context>
    <name>KSipIdentityEdit</name>
    <message>
        <source>Identity Editor</source>
        <translation>Editor de Identidade</translation>
    </message>
    <message>
        <source>Full Name:</source>
        <translation>Nome Completo:</translation>
    </message>
    <message>
        <source>User Part of SIP URL:</source>
        <translation>Parte de usuário da URL SIP:</translation>
    </message>
    <message>
        <source>Host Part of SIP URL:</source>
        <translation>Parte de host da URL SIP:</translation>
    </message>
    <message>
        <source>Outbound Proxy (optional):</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Authentication Username (optional):</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>q-value between 0.0-1.0 (optional):</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Auto Register</source>
        <translation>Registro Automático</translation>
    </message>
    <message>
        <source>Register</source>
        <translation>Registro</translation>
    </message>
    <message>
        <source>help button</source>
        <translation>botão ajuda</translation>
    </message>
    <message>
        <source>&amp;help...</source>
        <translation>&amp;Ajuda...</translation>
    </message>
    <message>
        <source>ok button</source>
        <translation>botão OK</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>cancel button</source>
        <translation>botão cancelar</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Ativo</translation>
    </message>
    <message>
        <source>Registration : </source>
        <translation>Registro:</translation>
    </message>
    <message>
        <source>Unregister</source>
        <translation>Remover Registro</translation>
    </message>
</context>
<context>
    <name>KSipOptions</name>
    <message>
        <source>URI to Request Options For:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Results:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Make Query</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>KSipPreferences</name>
    <message>
        <source>Global SIP Preferences</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hide Via</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Don&apos;t Hide</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Request Next Hop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Request Full Route</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Max Forwards</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>XML-File for Phone Book:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Expire Time of Registration (second):</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Expire Time of Presence Subscription (second):</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Socket Protocol (Kphone restart needed to apply change)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>UDP</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>TCP</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use STUN Server</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Yes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Symmetric Signalling</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Symmetric Media</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>STUN Server (address:port):</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Request Period for STUN Server (second):</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Media Min Port:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Media Max Port:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Call Preferences</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Busy Message:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Call Forwarding</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Inactive</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Active</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Forward to:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Call Forward Message:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>KSipRegistrations</name>
    <message>
        <source>off</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Identity</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Restart Kphone to apply identity changes.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Inactive</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Trying...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Auth Required...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Active</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unregistering...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reregistering...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Digest Authentication Request</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Basic Authentication Request</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Proxy Digest Authentication Request</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Proxy Basic Authentication Request</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>KTestOptions</name>
    <message>
        <source>Address:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Port:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Message:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clean</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Send</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Text files (*.txt)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>open file dialogChoose a file</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PhoneBook</name>
    <message>
        <source>Add</source>
        <translation>Adicionar</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Editar</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Remover</translation>
    </message>
    <message>
        <source>Hide</source>
        <translation>Esconder</translation>
    </message>
    <message>
        <source>Permanently rejected contacts</source>
        <translation>Contatos permanentemente rejeitados</translation>
    </message>
    <message>
        <source>PhoneBook</source>
        <translation>Agenda Telefônica</translation>
    </message>
    <message>
        <source>KPhone</source>
        <translation>KPhone</translation>
    </message>
    <message>
        <source>Select first item.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are You Sure ?</source>
        <translation>Você tem certeza?</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Sim</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Não</translation>
    </message>
</context>
<context>
    <name>PhoneBookAddIdentity</name>
    <message>
        <source>Person:</source>
        <translation>Pessoa:</translation>
    </message>
    <message>
        <source>Identity:</source>
        <translation>Identidade:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Descrção:</translation>
    </message>
    <message>
        <source>Add Identity to Contacts List</source>
        <translation>Adicionar identidade a lista de contatos</translation>
    </message>
    <message>
        <source>ok button</source>
        <translation>botão ok</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>cancel button</source>
        <translation>botão cancel</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
</context>
<context>
    <name>PhoneBookEditIdentity</name>
    <message>
        <source>Identity:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Description:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add Identity to Contacts List</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PhoneBookEditPerson</name>
    <message>
        <source>Name:</source>
        <translation>Nome:</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
</context>
<context>
    <name>PhoneBookParser</name>
    <message>
        <source>Identity</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Contact</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Description</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Permanently rejected contacts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Call Register</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Received calls</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Missed calls</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PhoneBook</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>description</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>contact</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SipCallMember</name>
    <message>
        <source>Response: </source>
        <translation></translation>
    </message>
    <message>
        <source>Connected: </source>
        <translation></translation>
    </message>
    <message>
        <source>Redirected: </source>
        <translation></translation>
    </message>
    <message>
        <source>Call Failed: </source>
        <translation></translation>
    </message>
    <message>
        <source>Disconnecting</source>
        <translation></translation>
    </message>
    <message>
        <source>Transfering</source>
        <translation></translation>
    </message>
    <message>
        <source>Querying options</source>
        <translation></translation>
    </message>
    <message>
        <source>Connected</source>
        <translation></translation>
    </message>
    <message>
        <source>Not Acceptable Here</source>
        <translation></translation>
    </message>
    <message>
        <source>Rejecting call invitation</source>
        <translation></translation>
    </message>
    <message>
        <source>Invitation received</source>
        <translation></translation>
    </message>
    <message>
        <source>Session update requested</source>
        <translation></translation>
    </message>
    <message>
        <source>Remote end disconnected</source>
        <translation></translation>
    </message>
    <message>
        <source>Refer</source>
        <translation></translation>
    </message>
    <message>
        <source>Request cancelled</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>SipTransaction</name>
    <message>
        <source>Online</source>
        <translation></translation>
    </message>
    <message>
        <source>Busy</source>
        <translation></translation>
    </message>
    <message>
        <source>Be Right Back</source>
        <translation></translation>
    </message>
    <message>
        <source>Away</source>
        <translation></translation>
    </message>
    <message>
        <source>On The Phone</source>
        <translation></translation>
    </message>
    <message>
        <source>Out To Lunch</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>VideoControl</name>
    <message>
        <source>Video Properties</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Preferred Video Codec</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>H261</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>H263</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ok button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>cancel button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>